--- htmlarea_orig.php	2008-01-04 11:30:55.000000000 +0100
+++ htmlarea.php	2008-01-28 10:36:10.000000000 +0100
@@ -63,7 +63,7 @@
     _editor_url = _editor_url.replace(/\x2f*$/, '/');
 } else {
     //alert("WARNING: _editor_url is not set!  You should set this variable to the editor files path; it should preferably be an absolute path, like in '/htmlarea', but it can be relative if you prefer.  Further we will try to load the editor files correctly but we'll probably fail.");
-    _editor_url = '<?php echo $url; ?>';// we need relative path to site root for editor in pages wit hrequired https
+    _editor_url = '<?php echo $url; ?>';// we need relative path to site root for editor in pages which required https
 }
 
 // make sure we have a language
@@ -2127,7 +2127,7 @@
         var cmd = null;
         var value = null;
 
-        if (ev.ctrlKey && !ev.altKey) {
+        if (ev.ctrlKey && !ev.altKey && !ev.shiftKey) {
             /**
              * Ctrl modifier only.
              * We use these for shortcuts that change existing content,
@@ -2218,9 +2218,9 @@
             } // End switch (key)
 
 
-        } else if (ev.ctrlKey && ev.altKey) {
+        } else if (ev.ctrlKey && !ev.altKey && ev.shiftKey) {
             /**
              * Ctrl + Alt modifiers.
              * We use these for shortcuts that insert stuff, e.g. images.
              */
             switch (key) {
@@ -2218,9 +2218,9 @@
             /**
-             * Ctrl + Alt modifiers.
+             * Ctrl + Shift modifiers.
              * We use these for shortcuts that insert stuff, e.g. images.
              */
